@@ -1,6 +1,7 @@
 import pandas as pd
-import numpy as np
 from mido import MidiTrack, MidiFile, MetaMessage, Message
+import io, pkgutil
+import os, sys
 
 def midi_to_df(mid):
     """Function to create a dataframe containing the
@@ -48,9 +49,9 @@ def tidy_df(dfc):
 
     """
 
+    df_unnest_wide = pd.DataFrame(list(dfc['msg']))
     df = pd.concat([dfc[['i_track', 'meta']],
-                    pd.DataFrame(list(dfc['msg']))
-                    ],
+                    df_unnest_wide],
                    axis = 1)
     return df
 
@@ -131,3 +132,20 @@ def compact_df(df, repair_reticulate_conversion = False):
                      ],
                      axis = 1)
     return dfc2
+
+
+def get_test_midi_file(as_string=False):
+    # midi_file = pkgutil.get_data(__name__, 'data/test_midi_file.mid') mostly
+    # inspired by
+    # https://stackoverflow.com/questions/5003755/how-to-use-pkgutils-get-data-with-csv-reader-in-python :
+    package = 'miditapyr'
+    loader = pkgutil.get_loader(package)
+    mod = sys.modules.get(package) or loader.load_module(package)
+    midi_file = os.path.dirname(mod.__file__) + '/data/test_midi_file.mid'
+    mido_midi_file = MidiFile(midi_file)
+    if as_string == False:
+        result = mido_midi_file
+    else:
+        result = midi_file
+    return result
+    # return midi_file
